 % Metoda Rayleighova podilu pro vypocet
 % dominantniho vlastniho cisla matice A(musi byt ctvercova) 
function[varargout]=raley(varargin)
% RALEY vypocet dominantniho vlastniho cisla
%
% RALEY(e,n,infile,outfile);
% e.........epsilon (zastavovaci podminka)
% n.........rad matice A (pri nacteni ze souboru max rad 10)
% infile....vstupni soubor pro nacteni matice A (nepovinny parametr)
% outfile...vystupni soubor pro zapis vysledku (nepovinny parametr)
%
% [A,l]=RALEY(e,n,infile,outfile);
% Funkce vrati matici A a jeji dominantni cislo l
% Pokud je psana funkce bez vystupnich promenych zobrazi se vysledek
% graficky
 if nargin<2,
   error('Nebyl zadn sprvn poet vstupnch parametr');
 end;
 if(isnumeric(varargin{1})==0)|(varargin{1}>=1),
     error('Spatne zadany vstup, epsilon musi byt cislo a mensi nez 1');
 end;  
 if (isnumeric(varargin{2})==0),
     error('Spatne zadany vstup, n musi byt cislo');
 end;
 if (varargin{2}>10),
    error('Prekrocen maxmalni rad matice, rad muze byt nejvice 10');
 else
     if (nargin>=3),
         if (ischar(varargin{3})==0),
             error('Nazev vstupniho souboru musi byt typu string');
         else
             A=dlmread(varargin{3},' ',[0 0 varargin{2}-1 varargin{2}-1]);
         end
     end
 end
 if (nargin==2),
    [A]=nacti_A(varargin{2}); 
 end;
 y1 = ones(size(A,1),1);
 pom = inf;
 lambda_stare = inf;
 while pom > varargin{1}
   y2 = A*y1;
   lambda_nove = (y1'*y2)/(y1'*y1);
   pom = abs(lambda_nove - lambda_stare);
   lambda_stare = lambda_nove;
   y1 = y2/norm(y2);
 end
 if (nargin==4),
     if (ischar(varargin{4})==0),
         error('Nazev vystupniho souboru musi byt typu string');
     else
         zapis_vyst(A,lambda_nove,varargin{4}); 
     end
 end
 if (nargout==0),
     surf(A);
     title(['Graf matice A. Jeho dominantni vlastni cislo je ',num2str(lambda_nove)]);
 else
     disp('Raleighuv podil z matice A');
     varargout{1}=A;
     disp('M dominantni vlastni cislo lambda');
     varargout{2}=lambda_nove;    
 end
 